@@ -1,5 +1,5 @@
 package Telegram::Bot::Brain;
-$Telegram::Bot::Brain::VERSION = '0.005';
+$Telegram::Bot::Brain::VERSION = '0.006';
 # ABSTRACT: A base class to make your very own Telegram bot
 
 
@@ -74,11 +74,12 @@ sub send_message_to_chat_id {
   my $self    = shift;
   my $chat_id = shift;
   my $message = shift;
+  my $opts    = shift || {};
 
   my $token = $self->token;
   my $msgURL = "https://api.telegram.org/bot${token}/sendMessage";
 
-  $self->ua->post($msgURL, form => { chat_id => $chat_id, text => $message });
+  $self->ua->post($msgURL, form => { %$opts, chat_id => $chat_id, text => $message });
 }
 
 sub add_getUpdates_handler {
@@ -149,7 +150,7 @@ Telegram::Bot::Brain - A base class to make your very own Telegram bot
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
 =head1 SYNOPSIS
 
@@ -216,6 +217,11 @@ Send a pre-constructed message (some subclass of L<Telegram::Bot::Message>) to a
 
 Send a plain text message to a chat_id (group or individual).
 
+Can be passed an optional hashref which is passed directly to the Telegram Bot API, for extra
+arguments like C<parse_mode> and so on.
+
+   $self->send_message_to_chat_id($msg->chat->id, "<pre>$text</pre>", { parse_mode => 'HTML' });
+
 =head1 SEE ALSO
 
 =over 4
